@@ -1,13 +1,60 @@
 package DTS::Task::DataPump;
 
+=head1 NAME
+
+DTS::Task::DataPump - a Perl subclass of DTS::Task to represent a DTSDataPumpTask object
+
+=head1 SYNOPSIS
+
+    use warnings;
+    use strict;
+    use DTS::Application;
+    use Test::More;
+    use XML::Simple;
+
+    my $xml    = XML::Simple->new();
+    my $config = $xml->XMLin('test-config.xml');
+
+    my $app = DTS::Application->new( $config->{credential} );
+
+    my $package = $app->get_db_package(
+        {
+            id               => '',
+            version_id       => '',
+            name             => $config->{package},
+            package_password => ''
+        }
+    );
+
+    foreach my $datapump ( @{ $package->get_datapumps } ) {
+
+        print $datapump->to_string, "\n";
+
+    }
+
+=head1 DESCRIPTION
+
+C<DTS::Task::DataPump> implements a convenient way to fetch properties from a DTS DataPumpTask Task object of a DTS
+Package.
+
+=head2 EXPORT
+
+Nothing.
+
+=cut
+
 use 5.008008;
 use strict;
 use warnings;
-use Carp;
+use Carp qw(confess);
 use base qw(DTS::Task Class::Accessor);
 use Hash::Util qw(lock_keys);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
+
+=head2 METHODS
+
+=cut
 
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_ro_accessors(
@@ -15,107 +62,13 @@ __PACKAGE__->mk_ro_accessors(
       commit_size max_errors)
 );
 
-# :WARNING:15/11/2006:ARFjr: This class is incomplete. There are several properties not defined
-# here that exists in the OLE API.
 
-sub use_single_file_7 {
+=head3 new
 
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
+Overrided method from L<DTS::Task|DTS::Task> to define additional attributes during object creation. See
+L<DTS::Task::new method|DTS::Task/new> for more information.
 
-    return $self->{single_file_7};
-
-}
-
-sub use_source_row_file {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{source_row_file};
-
-}
-
-sub use_error_file {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{overwrite};
-
-}
-
-sub overwrite_log_file {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{overwrite};
-
-}
-
-sub abort_on_log_failure {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{abort_on_log_failure};
-
-}
-
-sub use_destination_row_file {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{destination_row_file};
-
-}
-
-sub use_fast_load {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{use_fast_load};
-
-}
-
-sub log_is_ansi {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{is_ansi};
-
-}
-
-sub log_is_OEM {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{is_OEM};
-
-}
-
-sub log_is_unicode {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{is_unicode};
-
-}
-
-sub always_commit {
-
-    my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
-
-    return $self->{always_commit};
-
-}
+=cut
 
 sub new {
 
@@ -153,6 +106,177 @@ sub new {
 
 }
 
+=head3 use_single_file_7
+
+Returns true or false depending if errors, source, and destination exception rows are all written to a single ANSI file.
+
+=cut
+
+sub use_single_file_7 {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{single_file_7};
+
+}
+
+=head3 use_source_row_file
+
+Returns true or false depending if source exception rows are written to the source exception file.
+
+=cut
+
+sub use_source_row_file {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{source_row_file};
+
+}
+
+=head3 use_error_file
+
+Returns true or false if error rows are written to a error file.
+
+=cut
+
+sub use_error_file {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{overwrite};
+
+}
+
+=head3 overwrite_log_file
+
+Returns true or false if data is overwritten, rather than appended, to file.
+
+=cut
+
+sub overwrite_log_file {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{overwrite};
+
+}
+
+=head3 abort_on_log_failure
+
+Returns true or false if termination of the data pump if execution logging fails is enable.
+
+=cut
+
+sub abort_on_log_failure {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{abort_on_log_failure};
+
+}
+
+=head3 use_destination_row_file
+
+Returns true or false if destination exception rows are written to the destination exception file.
+
+=cut
+
+sub use_destination_row_file {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{destination_row_file};
+
+}
+
+=head3 use_fast_load
+
+Returns true or false if the use of the FastLoad option (where rows are processed in batches 
+under a single transaction commit) is enabled.
+
+=cut
+
+sub use_fast_load {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{use_fast_load};
+
+}
+
+=head3 log_is_ansi
+
+Returns true or false if the encoding of the log file is ANSI ASCII.
+
+=cut
+
+sub log_is_ansi {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{is_ansi};
+
+}
+
+=head3 log_is_OEM
+
+Returns true or false if the encoding of the log file is OEM.
+
+=cut
+
+sub log_is_OEM {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{is_OEM};
+
+}
+
+=head3 log_is_unicode
+
+Returns true or false if the encoding of the log file is Unicode (UTF-16LE).
+
+=cut
+
+sub log_is_unicode {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{is_unicode};
+
+}
+
+=head3 always_commit
+
+Returns true or false if the C<DataPumpTask> task will commit all successful batches including the final 
+batch, even if the data pump terminates. Use this option to support restartability.
+
+Strange as it may seen, this is called as I<Always commit> options in the DTS designer application, but received
+the name C<DataPumpOptions> property in the DTS API.
+
+=cut
+
+sub always_commit {
+
+    my ( $self, $write_attemp ) = shift;
+    confess "This is a read only method\n" if ( defined($write_attemp) );
+
+    return $self->{always_commit};
+
+}
+
+
 sub _get_exception_file_options {
 
     my $self = shift;
@@ -238,27 +362,45 @@ sub _get_exception_file_options {
     $self->{is_ansi} = 1 if ( $self->{single_file_7} );
 }
 
+=head3 use_check_constraints
+
+Returns true or false if the datapump will check for the constrainst of the table before inserting new rows.
+
+=cut
+
 sub use_check_constraints {
 
     my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
+    confess "This is a read only method\n" if ( defined($write_attemp) );
 
     return $self->{check_constraints};
 
 }
 
+=head3 use_keep_nulls
+
+Returns true or false if the datapump will insert will insert NULL values from the data source into the destination.
+
+=cut
+
 sub use_keep_nulls {
 
     my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
+    confess "This is a read only method\n" if ( defined($write_attemp) );
 
     return $self->{keep_nulls};
 }
 
+=head3 use_lock_table
+
+Returns true or false if the datapump will lock the entire table instead using lock by page.
+
+=cut
+
 sub use_lock_table {
 
     my ( $self, $write_attemp ) = shift;
-    croak "This is a read only method\n" if ( defined($write_attemp) );
+    confess "This is a read only method\n" if ( defined($write_attemp) );
 
     return $self->{lock_table};
 }
@@ -275,6 +417,7 @@ sub _get_fast_load_options {
     my $self         = shift;
     my $numeric_code = $self->get_sibling->Properties->Parent->FastLoadOptions;
 
+    # sanity checking
     $self->{check_constraints} = 0;
     $self->{keep_nulls}        = 0;
     $self->{lock_table}        = 0;
@@ -283,53 +426,26 @@ sub _get_fast_load_options {
 
         if ( $numeric_code == 0 ) {
 
-            # do nothing
+            # do nothing, besides there is nothing to do anyway
             last CHECK;
 
         }
 
-        if ( $numeric_code == 1 ) {
+        if ( ( $numeric_code && 1 ) == 1 ) {
 
             $self->{keep_nulls} = 1;
-            last CHECK;
 
         }
 
-        if ( $numeric_code == 2 ) {
+        if ( ( $numeric_code && 2 ) == 2 ) {
 
             $self->{check_constraints} = 1;
-            last CHECK;
 
         }
 
-        if ( $numeric_code == 3 ) {
-
-            $self->{keep_nulls}        = 1;
-            $self->{check_constraints} = 1;
-            last CHECK;
-
-        }
-
-        if ( $numeric_code == 4 ) {
+        if ( ( $numeric_code && 4 ) == 4 ) {
 
             $self->{lock_table} = 1;
-            last CHECK;
-
-        }
-
-        if ( $numeric_code == 5 ) {
-
-            $self->{keep_nulls} = 1;
-            $self->{lock_table} = 1;
-            last CHECK;
-        }
-
-        if ( $numeric_code == 7 ) {
-
-            $self->{keep_nulls}        = 1;
-            $self->{lock_table}        = 1;
-            $self->{check_constraints} = 1;
-            last CHECK;
 
         }
 
@@ -337,6 +453,12 @@ sub _get_fast_load_options {
 
 }
 
+=head3 use_identity_inserts
+
+Returns true or false if I<Identity inserts> will be used.
+
+=cut
+
 sub use_identity_inserts {
 
     my $self = shift;
@@ -344,6 +466,13 @@ sub use_identity_inserts {
 
 }
 
+=head3 to_string
+
+Returns a string with all attributes from the datapump object, separated by new line characters and with a
+short description of each attribute.
+
+=cut
+
 sub to_string {
 
     my $self = shift;
@@ -394,6 +523,15 @@ sub to_string {
 
 }
 
+=head3 get_input_global_vars
+
+Returns a string or a list of Data Transformation Services (DTS) global variable names that are to be 
+used as parameters in a query or created in a subpackage, depending on the context that the method is invoked.
+
+The returned string is made of the global variable names separated by semi-colons characters.
+
+=cut
+
 sub get_input_global_vars {
 
     my $self = shift;
@@ -415,170 +553,6 @@ sub get_input_global_vars {
 
 }
 
-sub get_properties {
-
-    my $self = shift;
-    return [
-        $self->use_single_file_7,    $self->use_source_row_file,
-        $self->use_error_file,       $self->overwrite_log_file,
-        $self->abort_on_log_failure, $self->use_destination_row_file,
-        $self->use_fast_load,        $self->log_is_ansi,
-        $self->log_is_OEM,           $self->log_is_unicode,
-        $self->always_commit,        $self->use_check_constraints,
-        $self->use_keep_nulls,       $self->use_lock_table,
-        $self->use_identity_inserts, $self->get_input_global_vars,
-        $self->get_rows_complete,    $self->get_exception_file,
-        $self->get_commit_size,      $self->get_max_errors
-      ]
-
-}
-
-1;
-
-__END__
-
-=head1 NAME
-
-DTS::Task::DataPump - a Perl subclass of DTS::Task to represent a DTSDataPumpTask object
-
-=head1 SYNOPSIS
-
-    use warnings;
-    use strict;
-    use DTS::Application;
-    use Test::More;
-    use XML::Simple;
-
-    my $xml    = XML::Simple->new();
-    my $config = $xml->XMLin('test-config.xml');
-
-    my $app = DTS::Application->new( $config->{credential} );
-
-    my $package = $app->get_db_package(
-        {
-            id               => '',
-            version_id       => '',
-            name             => $config->{package},
-            package_password => ''
-        }
-    );
-
-    foreach my $datapump ( @{ $package->get_datapumps } ) {
-
-        print $datapump->to_string, "\n";
-
-    }
-
-=head1 DESCRIPTION
-
-C<DTS::Task::DataPump> implements a convenient way to fetch properties from a DTS DataPumpTask Task object of a DTS
-Package.
-
-=head2 EXPORT
-
-None by default.
-
-=head2 METHODS
-
-=head3 new
-
-Overrided method from L<DTS::Task|DTS::Task> to define additional attributes during object creation. See
-L<DTS::Task::new method|DTS::Task/new> for more information.
-
-=head3 use_single_file_7
-
-Returns true or false depending if errors, source, and destination exception rows are all written to a single ANSI file.
-
-=head3 use_source_row_file
-
-Returns true or false depending if source exception rows are written to the source exception file.
-
-=head3 use_error_file
-
-Returns true or false if error rows are written to a error file.
-
-=head3 overwrite_log_file
-
-Returns true or false if data is overwritten, rather than appended, to file.
-
-=head3 abort_on_log_failure
-
-Returns true or false if termination of the data pump if execution logging fails is enable.
-
-=head3 use_destination_row_file
-
-Returns true or false if destination exception rows are written to the destination exception file.
-
-=head3 use_fast_load
-
-Returns true or false if the use of the FastLoad option (where rows are processed in batches 
-under a single transaction commit) is enabled.
-
-=head3 log_is_ansi
-
-Returns true or false if the encoding of the log file is ANSI ASCII.
-
-=head3 log_is_OEM
-
-Returns true or false if the encoding of the log file is OEM.
-
-=head3 log_is_unicode
-
-Returns true or false if the encoding of the log file is Unicode (UTF-16LE).
-
-=head3 always_commit
-
-Returns true or false if the C<DataPumpTask> task will commit all successful batches including the final 
-batch, even if the data pump terminates. Use this option to support restartability.
-
-Strange as it may seen, this is called as I<Always commit> options in the DTS designer application, but received
-the name C<DataPumpOptions> property in the DTS API.
-
-=head3 use_check_constraints
-
-Returns true or false if the datapump will check for the constrainst of the table before inserting new rows.
-
-=head3 use_keep_nulls
-
-Returns true or false if the datapump will insert will insert NULL values from the data source into the destination.
-
-=head3 use_lock_table
-
-Returns true or false if the datapump will lock the entire table instead using lock by page.
-
-=head3 use_identity_inserts
-
-Returns true or false if I<Identity inserts> will be used.
-
-=head3 to_string
-
-Returns a string with all attributes from the datapump object, separated by new line characters and with a
-short description of each attribute.
-
-=head3 get_input_global_vars
-
-Returns a string or a list of Data Transformation Services (DTS) global variable names that are to be 
-used as parameters in a query or created in a subpackage, depending on the context that the method is invoked.
-
-The returned string is made of the global variable names separated by semi-colons characters.
-
-=head3 get_rows_complete
-
-Returns the number of source rows, including rows for which errors occurred, processed by the task 
-or transformation set.
-
-=head3 get_exception_file
-
-Returns the file name path where exception rows are written.
-
-=head3 get_commit_size
-
-Returns the number of rows that are inserted in a single transaction when the FastLoad option is being used.
-
-=head3 get_max_errors
-
-Returns the maximum number of error rows before the data pump terminates.
-
 =head3 get_properties
 
 Returns an array reference with the values of the attributes of a C<DTS::Task::DataPump> in the order 
@@ -648,6 +622,51 @@ max_errors
 
 =back
 
+=cut
+
+sub get_properties {
+
+    my $self = shift;
+    return [
+        $self->use_single_file_7,    $self->use_source_row_file,
+        $self->use_error_file,       $self->overwrite_log_file,
+        $self->abort_on_log_failure, $self->use_destination_row_file,
+        $self->use_fast_load,        $self->log_is_ansi,
+        $self->log_is_OEM,           $self->log_is_unicode,
+        $self->always_commit,        $self->use_check_constraints,
+        $self->use_keep_nulls,       $self->use_lock_table,
+        $self->use_identity_inserts, $self->get_input_global_vars,
+        $self->get_rows_complete,    $self->get_exception_file,
+        $self->get_commit_size,      $self->get_max_errors
+      ]
+
+}
+
+1;
+
+__END__
+
+=head3 get_rows_complete
+
+Returns the number of source rows, including rows for which errors occurred, processed by the task 
+or transformation set.
+
+=head3 get_exception_file
+
+Returns the file name path where exception rows are written.
+
+=head3 get_commit_size
+
+Returns the number of rows that are inserted in a single transaction when the FastLoad option is being used.
+
+=head3 get_max_errors
+
+Returns the maximum number of error rows before the data pump terminates.
+
+=head2 CAVEATS
+
+This class is incomplete. There are several properties not defined here that exists in the DTS API.
+
 =head1 SEE ALSO
 
 =over
@@ -666,7 +685,7 @@ object hierarchy, but one will need to convert examples written in VBScript to P
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>glasswalk3r@yahoo.com.brE<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -676,6 +695,5 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
 
